uv_demo API documentation

# uv_demo

The uv-demo package.

View Source

     1"""The uv-demo package."""
     2
     3from importlib.metadata import version
     4
     5from .greetings import LIB_NAME, say_goodbye, say_hello
     6
     7__version__ = version(LIB_NAME)
     8
     9__all__ = [
    10    "__version__",
    11    "LIB_NAME",
    12    "say_hello",
    13    "say_goodbye",
    14]

__version__ = '0.2.4'
LIB_NAME = 'uv_demo'
def say_hello() -> None: View Source

    10def say_hello() -> None:
    11    """Entrypoint for uv-demo."""
    12    log.info("This message should not be seen by most users.")
    13    print("Hello from uv-demo!")

Entrypoint for uv-demo.

def say_goodbye() -> None: View Source

    16def say_goodbye() -> None:
    17    """Another entrypoint for uv-demo."""
    18    log.info("This message should not be seen by most users.")
    19    print("Goodbye from uv-demo!")

Another entrypoint for uv-demo.